@@ -2,7 +2,7 @@
                           resource.h  -  description
                           --------------------------
     copyright            : (C) 2000 by Torsten Henschel
-    email                : henschel@fh-brandenburg.de
+    email                : thenschel@henschelsoft.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,15 +21,18 @@
 #include <config.h>
 #endif
 
-///////////////////////////////////////////////////////////////////
 // COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES
-///////////////////////////////////////////////////////////////////
+
 
 // Define generic command codes
-#define ID_EXIT								100
-#define ID_NEW_POPUP	 				120
-#define ID_ANSWER_POPUP				140
-#define ID_STATUS_TEXT				160
-#define ID_HELP               180
+#define ID_EXIT                 100
+#define ID_NEW_POPUP            120
+#define ID_ANSWER_POPUP         140
+#define ID_STATUS_TEXT          160
+#define ID_HELP                 180
+#define ID_PREVIOUS_POPUP       200
+#define ID_NEXT_POPUP           220
+#define ID_DELETE_POPUP         240
+#define ID_MIN_POPUP            260
 
 #endif
